==> tencentcloud-sdk-java-3.1.87-sources.jar: com/tencentcloudapi/smpn/v20190822/models/EPAResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.smpn.v20190822.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class EPAResponse extends AbstractModel{

    /**
    * 0成功 其他失败
    */
    @SerializedName("RetCode")
    @Expose
    private Long RetCode;

    /**
     * Get 0成功 其他失败 
     * @return RetCode 0成功 其他失败
     */
    public Long getRetCode() {
        return this.RetCode;
    }

    /**
     * Set 0成功 其他失败
     * @param RetCode 0成功 其他失败
     */
    public void setRetCode(Long RetCode) {
        this.RetCode = RetCode;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "RetCode", this.RetCode);

    }
}

==> tencentcloud-sdk-java-3.1.281-sources.jar: com/tencentcloudapi/smpn/v20190822/models/EPAResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.smpn.v20190822.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class EPAResponse extends AbstractModel{

    /**
    * 0成功 其他失败
    */
    @SerializedName("RetCode")
    @Expose
    private Long RetCode;

    /**
     * Get 0成功 其他失败 
     * @return RetCode 0成功 其他失败
     */
    public Long getRetCode() {
        return this.RetCode;
    }

    /**
     * Set 0成功 其他失败
     * @param RetCode 0成功 其他失败
     */
    public void setRetCode(Long RetCode) {
        this.RetCode = RetCode;
    }

    public EPAResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public EPAResponse(EPAResponse source) {
        if (source.RetCode != null) {
            this.RetCode = new Long(source.RetCode);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "RetCode", this.RetCode);

    }
}
